buffet: Remove 'chromeos' namespace and move everything to buffet NS

As discussed, moved all the classes out of chromeos namespace into
'buffet.

Also fixed a number of cpplint's warnings.

BUG=None
TEST=Everything still compiles and unit tests succeed.

Change-Id: Ide864acb2504627404966727f66d353af60e531d
Reviewed-on: https://chromium-review.googlesource.com/198971
Reviewed-by: Christopher Wiley <wiley@chromium.org>
Commit-Queue: Alex Vakulenko <avakulenko@chromium.org>
Tested-by: Alex Vakulenko <avakulenko@chromium.org>
diff --git a/buffet/url_utils.h b/buffet/url_utils.h
index f08cf45..d9bce25 100644
--- a/buffet/url_utils.h
+++ b/buffet/url_utils.h
@@ -5,12 +5,14 @@
 #ifndef BUFFET_URL_UTILS_H_
 #define BUFFET_URL_UTILS_H_
 
-#include <base/basictypes.h>
 #include <string>
 #include <vector>
+
+#include <base/basictypes.h>
+
 #include "buffet/data_encoding.h"
 
-namespace chromeos {
+namespace buffet {
 
 namespace url {
 
@@ -23,7 +25,7 @@
     const std::vector<std::string>& parts) WARN_UNUSED_RESULT;
 
 // Removes the query string/fragment from |url| and returns the query string.
-// This method actiually modifies |url|. So, if you call it on this:
+// This method actually modifies |url|. So, if you call it on this:
 //    http://www.test.org/?foo=bar
 // it will modify |url| to "http://www.test.org/" and return "?foo=bar"
 std::string TrimOffQueryString(std::string* url);
@@ -34,7 +36,7 @@
 // Here:
 //    http://server.com/path/to/object - is the URL of the object,
 //    ?k=v&foo=bar                     - URL query string
-//    #fragment                        - URL framgment string
+//    #fragment                        - URL fragment string
 // If |remove_fragment| is true, the function returns the query string without
 // the fragment. Otherwise the fragment is included as part of the result.
 std::string GetQueryString(const std::string& url, bool remove_fragment);
@@ -69,7 +71,7 @@
 // Checks if the URL has query parameters.
 bool HasQueryString(const std::string& url);
 
-} // namespace url
-} // namespace chromeos
+}  // namespace url
+}  // namespace buffet
 
-#endif // BUFFET_URL_UTILS_H_
+#endif  // BUFFET_URL_UTILS_H_